You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@tinkerpop.apache.org by sp...@apache.org on 2015/04/15 14:24:11 UTC

[2/6] incubator-tinkerpop git commit: Change gremlin.tests to gremlin_tests

Change gremlin.tests to gremlin_tests

Bash env var names in the "export" syntax must be alphanumeric plus underscore.
Workarounds involving "env" syntax are cumbersome.


Project: http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/commit/6556e191
Tree: http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/tree/6556e191
Diff: http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/diff/6556e191

Branch: refs/heads/master
Commit: 6556e1918750850fcd23fae918fa9b73e98531a9
Parents: 4e9c94a
Author: mhfrantz <mf...@redsealnetworks.com>
Authored: Tue Apr 14 10:18:29 2015 -0700
Committer: mhfrantz <mf...@redsealnetworks.com>
Committed: Tue Apr 14 10:18:29 2015 -0700

----------------------------------------------------------------------
 .../java/org/apache/tinkerpop/gremlin/AbstractGremlinSuite.java  | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/6556e191/gremlin-test/src/main/java/org/apache/tinkerpop/gremlin/AbstractGremlinSuite.java
----------------------------------------------------------------------
diff --git a/gremlin-test/src/main/java/org/apache/tinkerpop/gremlin/AbstractGremlinSuite.java b/gremlin-test/src/main/java/org/apache/tinkerpop/gremlin/AbstractGremlinSuite.java
index 6a7cbd9..c3edeed 100644
--- a/gremlin-test/src/main/java/org/apache/tinkerpop/gremlin/AbstractGremlinSuite.java
+++ b/gremlin-test/src/main/java/org/apache/tinkerpop/gremlin/AbstractGremlinSuite.java
@@ -164,13 +164,13 @@ public abstract class AbstractGremlinSuite extends Suite {
     }
 
     /**
      * Filter a list of test classes through the gremlin.tests environment variable list.
      */
     private static Class<?>[] filterSpecifiedTests(Class<?>[] allTests) {
         if (null == allTests) return allTests;
 
         Class<?>[] filteredTests;
-        final String override = System.getenv().getOrDefault("gremlin.tests", "");
+        final String override = System.getenv().getOrDefault("gremlin_tests", "");
         if (override.equals(""))
             filteredTests = allTests;
         else {
@@ -164,13 +164,13 @@ public abstract class AbstractGremlinSuite extends Suite {
 
     /**
-     * Filter a list of test classes through the gremlin.tests environment variable list.
+     * Filter a list of test classes through the gremlin_tests environment variable list.
      */
     private static Class<?>[] filterSpecifiedTests(Class<?>[] allTests) {